==> lirc-0.9.2a.tar.bz2: api-docs/html/lirc__client_8c.js <==
var lirc__client_8c =
[
    [ "_BSD_SOURCE", "lirc__client_8c.html#ad3d8a3bd0c0b677acef144f2c2ef6d73", null ],
    [ "_XOPEN_SOURCE", "lirc__client_8c.html#a78c99ffd76a7bb3c8c74db76207e9ab4", null ],
    [ "LIRC_DEBUG", "lirc__client_8c.html#af5357380e149299d3a1e0a9093099ae7", null ],
    [ "LIRC_ERROR", "lirc__client_8c.html#a1bebef4e51d33fdcec21c23f92d2a1ce", null ],
    [ "LIRC_NOTICE", "lirc__client_8c.html#ac88335e77f628f6ef9ed4c19e602e3d3", null ],
    [ "LIRC_PACKET_SIZE", "lirc__client_8c.html#a07d195aee7fdaff04b0c355c73df87d7", null ],
    [ "LIRC_READ", "lirc__client_8c.html#ac6e57f9be3794a5dcd438d17f33ab29a", null ],
    [ "LIRC_TIMEOUT", "lirc__client_8c.html#a636447c3c5d66db20560d4c4334908e8", null ],
    [ "LIRC_WARNING", "lirc__client_8c.html#a49ef8059bbf3cba1d8f19d556e094cf2", null ],
    [ "logprintf", "lirc__client_8c.html#ad9b2c6ff79b021714752fd50ae05d9a5", null ],
    [ "MAX_INCLUDES", "lirc__client_8c.html#a5319bb0b2d15e5b98751faa7c92cc1cf", null ],
    [ "packet_state", "lirc__client_8c.html#aacdc622aa02a946d7a3d67c361199733", [
      [ "P_BEGIN", "lirc__client_8c.html#aacdc622aa02a946d7a3d67c361199733a4c27b76c1e91aa091061149366a3e5c7", null ],
      [ "P_MESSAGE", "lirc__client_8c.html#aacdc622aa02a946d7a3d67c361199733a179c4b9c0d9e6ce3419f62801d5a307d", null ],
      [ "P_STATUS", "lirc__client_8c.html#aacdc622aa02a946d7a3d67c361199733a9afa2f7ba250e81906756571b8863ca8", null ],
      [ "P_DATA", "lirc__client_8c.html#aacdc622aa02a946d7a3d67c361199733a8834181b4738023da319624f8fa76b8e", null ],
      [ "P_N", "lirc__client_8c.html#aacdc622aa02a946d7a3d67c361199733aeae3944f614e248396d2cda64dac9327", null ],
      [ "P_DATA_N", "lirc__client_8c.html#aacdc622aa02a946d7a3d67c361199733ac48b93dc3eff6b38e9753dc05113a385", null ],
      [ "P_END", "lirc__client_8c.html#aacdc622aa02a946d7a3d67c361199733a5eaa42e2b8e5e1d0380e268686df14b5", null ]
    ] ],
    [ "lirc_code2char", "group__lirc__client.html#ga8cb15780179dec56adc42559ee964a68", null ],
    [ "lirc_code2charprog", "group__lirc__client.html#ga5d24b619ef689329ae2d085aa2bd412b", null ],
    [ "lirc_command_init", "group__lirc__client.html#ga3787c58d32391a5b7c40337fdbee95fc", null ],
    [ "lirc_command_reply_to_stdout", "group__lirc__client.html#gace4d40f00918d8bdf9a4f6df0fb0155d", null ],
    [ "lirc_command_run", "group__lirc__client.html#ga888d275e1b0cf4988e44fb15f24d2a99", null ],
    [ "lirc_deinit", "group__lirc__client.html#ga50999022b09857ba43aa2f3f29c72b9e", null ],
    [ "lirc_flags", "lirc__client_8c.html#accf091efd8c192e8437cb2d6d62029c6", null ],
    [ "lirc_freeconfig", "group__lirc__client.html#ga771f0592a8d378bc2ea314fdf4efa233", null ],
    [ "lirc_get_local_socket", "group__lirc__client.html#ga13cf4c784df60143d2b171645f4e84c1", null ],
    [ "lirc_get_remote_socket", "group__lirc__client.html#ga81b8a02fdab2ef6d21930bbefabedf30", null ],
    [ "lirc_getmode", "group__lirc__client.html#ga5161b44df0f73abbc48db605c98c9279", null ],
    [ "lirc_getsocketname", "group__lirc__client.html#gac572a64d1d7abbe776957c4fc7273bb7", null ],
    [ "lirc_identify", "lirc__client_8c.html#a709e5f7e03d61cdd952cef662ea676ab", null ],
    [ "lirc_init", "group__lirc__client.html#gaf92c865f0895259aa40e2aed51c71001", null ],
    [ "lirc_ir2char", "group__lirc__client.html#gab9031bb1af5f068bacb1fe0d1fc6ca81", null ],
    [ "lirc_mode", "lirc__client_8c.html#a11bbfdf6cf44a0b747d83632ffb83d01", null ],
    [ "lirc_nextcode", "group__lirc__client.html#gaf352dc9bb17d32c0f867ce5ca8a2f2d3", null ],
    [ "lirc_nextir", "group__lirc__client.html#gafab5b5f56fb8bfb65b67d56d8426c2e1", null ],
    [ "lirc_readconfig", "group__lirc__client.html#ga62e50c43a39bd8858d42bc11adf40972", null ],
    [ "lirc_readconfig_only", "group__lirc__client.html#ga94642edfbd32527a6a9b9c761be9ad90", null ],
    [ "lirc_send_one", "group__lirc__client.html#ga0e86e3a29c14dc8047651e0bb9c49b31", null ],
    [ "lirc_setmode", "group__lirc__client.html#ga28252340557d024ff5238c69f3875a38", null ],
    [ "lirc_simulate", "group__lirc__client.html#gad5d41d33e0c1fc3002cdf8c0d9aa43d5", null ],
    [ "prog", "lirc__client_8c.html#acc6113e98e7cd24d9dcfa520749a5d3f", null ]
];

==> lirc-0.10.1.tar.bz2: api-docs/html/lirc__client_8c.js <==
var lirc__client_8c =
[
    [ "LIRC_DEBUG", "lirc__client_8c.html#af5357380e149299d3a1e0a9093099ae7", null ],
    [ "LIRC_ERROR", "lirc__client_8c.html#a1bebef4e51d33fdcec21c23f92d2a1ce", null ],
    [ "LIRC_NOTICE", "lirc__client_8c.html#ac88335e77f628f6ef9ed4c19e602e3d3", null ],
    [ "LIRC_PACKET_SIZE", "lirc__client_8c.html#a07d195aee7fdaff04b0c355c73df87d7", null ],
    [ "LIRC_READ", "lirc__client_8c.html#ac6e57f9be3794a5dcd438d17f33ab29a", null ],
    [ "LIRC_TIMEOUT", "lirc__client_8c.html#a636447c3c5d66db20560d4c4334908e8", null ],
    [ "LIRC_WARNING", "lirc__client_8c.html#a49ef8059bbf3cba1d8f19d556e094cf2", null ],
    [ "logprintf", "lirc__client_8c.html#ae521ac23108a443e4d2c7a59a0d8f04b", null ],
    [ "MAX_INCLUDES", "lirc__client_8c.html#a5319bb0b2d15e5b98751faa7c92cc1cf", null ],
    [ "MAXPATHLEN", "lirc__client_8c.html#addfa831c1473e710d2b71b72fd7fcfa5", null ],
    [ "packet_state", "lirc__client_8c.html#aacdc622aa02a946d7a3d67c361199733", [
      [ "P_BEGIN", "lirc__client_8c.html#aacdc622aa02a946d7a3d67c361199733a4c27b76c1e91aa091061149366a3e5c7", null ],
      [ "P_MESSAGE", "lirc__client_8c.html#aacdc622aa02a946d7a3d67c361199733a179c4b9c0d9e6ce3419f62801d5a307d", null ],
      [ "P_STATUS", "lirc__client_8c.html#aacdc622aa02a946d7a3d67c361199733a9afa2f7ba250e81906756571b8863ca8", null ],
      [ "P_DATA", "lirc__client_8c.html#aacdc622aa02a946d7a3d67c361199733a8834181b4738023da319624f8fa76b8e", null ],
      [ "P_N", "lirc__client_8c.html#aacdc622aa02a946d7a3d67c361199733aeae3944f614e248396d2cda64dac9327", null ],
      [ "P_DATA_N", "lirc__client_8c.html#aacdc622aa02a946d7a3d67c361199733ac48b93dc3eff6b38e9753dc05113a385", null ],
      [ "P_END", "lirc__client_8c.html#aacdc622aa02a946d7a3d67c361199733a5eaa42e2b8e5e1d0380e268686df14b5", null ]
    ] ],
    [ "lirc_code2char", "group__lirc__client.html#ga8cb15780179dec56adc42559ee964a68", null ],
    [ "lirc_code2charprog", "group__lirc__client.html#ga5d24b619ef689329ae2d085aa2bd412b", null ],
    [ "lirc_command_init", "group__lirc__client.html#ga3787c58d32391a5b7c40337fdbee95fc", null ],
    [ "lirc_command_reply_to_stdout", "group__lirc__client.html#gace4d40f00918d8bdf9a4f6df0fb0155d", null ],
    [ "lirc_command_run", "group__lirc__client.html#ga888d275e1b0cf4988e44fb15f24d2a99", null ],
    [ "lirc_deinit", "group__lirc__client.html#ga50999022b09857ba43aa2f3f29c72b9e", null ],
    [ "lirc_flags", "lirc__client_8c.html#accf091efd8c192e8437cb2d6d62029c6", null ],
    [ "lirc_freeconfig", "group__lirc__client.html#ga771f0592a8d378bc2ea314fdf4efa233", null ],
    [ "lirc_get_local_socket", "group__lirc__client.html#ga13cf4c784df60143d2b171645f4e84c1", null ],
    [ "lirc_get_remote_socket", "group__lirc__client.html#ga81b8a02fdab2ef6d21930bbefabedf30", null ],
    [ "lirc_getmode", "group__lirc__client.html#ga5161b44df0f73abbc48db605c98c9279", null ],
    [ "lirc_getsocketname", "group__lirc__client.html#gac572a64d1d7abbe776957c4fc7273bb7", null ],
    [ "lirc_identify", "lirc__client_8c.html#a709e5f7e03d61cdd952cef662ea676ab", null ],
    [ "lirc_init", "group__lirc__client.html#gaf92c865f0895259aa40e2aed51c71001", null ],
    [ "lirc_ir2char", "group__lirc__client.html#gab9031bb1af5f068bacb1fe0d1fc6ca81", null ],
    [ "lirc_mode", "lirc__client_8c.html#a11bbfdf6cf44a0b747d83632ffb83d01", null ],
    [ "lirc_nextcode", "group__lirc__client.html#gaf352dc9bb17d32c0f867ce5ca8a2f2d3", null ],
    [ "lirc_nextir", "group__lirc__client.html#gafab5b5f56fb8bfb65b67d56d8426c2e1", null ],
    [ "lirc_readconfig", "group__lirc__client.html#ga62e50c43a39bd8858d42bc11adf40972", null ],
    [ "lirc_readconfig_only", "group__lirc__client.html#ga94642edfbd32527a6a9b9c761be9ad90", null ],
    [ "lirc_send_one", "group__lirc__client.html#ga0e86e3a29c14dc8047651e0bb9c49b31", null ],
    [ "lirc_setmode", "group__lirc__client.html#ga28252340557d024ff5238c69f3875a38", null ],
    [ "lirc_simulate", "group__lirc__client.html#gad5d41d33e0c1fc3002cdf8c0d9aa43d5", null ],
    [ "prog", "lirc__client_8c.html#acc6113e98e7cd24d9dcfa520749a5d3f", null ]
];
